Enum PayloadFormat
pub enum PayloadFormat {
Json,
Cbor,
}Expand description
Supported payload formats for MQTT messages.
This type represents the payload format segment used in the command topics.
Variants
Implementations
impl PayloadFormat
impl PayloadFormat
pub fn serialize<T>(self, value: &T) -> Result<Vec<u8>>where
T: Serialize,
pub fn serialize<T>(self, value: &T) -> Result<Vec<u8>>where
T: Serialize,
Serializes the given value according to the payload format.
pub fn deserialize<T>(self, payload: &[u8]) -> Result<T>where
T: DeserializeOwned,
pub fn deserialize<T>(self, payload: &[u8]) -> Result<T>where
T: DeserializeOwned,
Deserializes data from the given payload according to the payload format.